pub struct Diagnostics { /* private fields */ }Expand description
Diagnostics
Provides detailed information about how a policy decision was made, including policies that contributed to the decision and any errors encountered during evaluation.
Implementations
Sourceimpl Diagnostics
impl Diagnostics
Sourcepub fn reason(&self) -> Vec<String>
pub fn reason(&self) -> Vec<String>
PolicyIds of the policies that contributed to the decision.
If no policies applied to the request, this set will be empty.
The ids should be treated as unordered,
Sourcepub fn errors(&self) -> Vec<PolicyEvaluationError>
pub fn errors(&self) -> Vec<PolicyEvaluationError>
Errors that occurred during authorization. The errors should be treated as unordered, since policies may be evaluated in any order.